from setuptools import setup

setup(name='distr_probab',
      version='0.2',
      description='Gaussian and Binomial distributions',
      packages=['distr_probab'],
      author='Sagar Das',
      author_email = 'sagarrdass@gmail.com',
      zip_safe=False)
